from py_pari import *
def foo0():	"""
py_pari -- Python interface to PARI C-library.

This module allows you to use Python *instead* of gp, with minimal
performance penalty, and all the advantages associated with Python
being a real programming language:

      - Easier memory management:
            Garbage collection finally!
            
            Also, if the "PARI stack overflows", then the amount of
            memory used by PARI is automatically doubled, all the PARI
            objects are correctly updated, and your computation
            continues automatically.

      - Exception handling
      
      - Class definitions
      
      - Object serialization of any PARI object whose string
        representation evaluates to the object, e.g.,
            >>> a = pari(5)
            >>> import pickle
            >>> s = pickle.dumps(a); 
            >>> z = pickle.loads(s);
            >>> print z
            5
            >>> type(z)
            <type 'py_pari.gen'>
            >>> a == z
            True
            >>> a is z
            False

WARNINGS:

  * Never import this module twice.  Your program will freeze.
  
  * PARI commands run at the C-level and cannot be interupted
    from the Python interpreter with ctrl-C until they are finished.
    
"""

def foo1():	"""
    Initialize the PARI system.
    
    INPUT:
        size -- long, the number of bytes for the initial PARI stack
                (see note below)
        maxprime -- unsigned long, upper limit on a precomputed prime
                    number table  (default: 2000000)

    NOTES:
    
        * In py_pari, the PARI stack is different than in gp or the
          PARI C library.  In Python, instead of the PARI stack
          holding the results of all computations, it *only* holds the
          results of an individual computation.  Each time a new
          Python/PARI object is computed, it it copied to its own
          space in the Python heap, and the memory it occupied on the
          PARI stack is freed.  Thus it is not necessary to make the
          stack very large.  Also, unlike in PARI, if the stack does
          overflow, in most cases the PARI stack is automatically
          increased and the relevant step of the computation rerun.

          This design obviously involves some performance penalties
          over the way PARI works, but it scales much better and is
          far more robus for large projects.
          
        * If you do not want prime numbers, put maxprime=2, but be
          careful because many PARI functions require this table.  If
          you get the error message "not enough precomputed primes",
          increase this parameter.
          
    """

def foo2():	"""
            g -- PARI GEN
            b -- pointer to memory chunk where PARI gen lives
                 (if nonzero then this memory is freed when the object
                  goes out of scope)
        """

def foo3():	"""
        Return a *copy* of the nth entry.

        The indexing is 0-based, like in Python.  However, *copying*
        the nth entry instead of returning reference is different
        than what one usually does in Python.  However, we do it
        this way for consistency with the PARI/GP interpreter, which
        does make copies.
        """

def foo4():	"""
        Set the nth entry to a *copy* of x.  
        
        The indexing is 0-based, like in Python.  However, setting
        the nth entry to a *copy* instead of a reference is different
        than what one usually does in Python.  However, we do it
        this way for consistency with the PARI/GP interpreter, which
        does make copies.
        """

def foo5():	"""
        isprime(x, flag=0): Returns true (1) if x is a PROVEN prime
        number, and false (0) otherwise. 

        INPUT:
            flag -- int 
                    0 (default): use a combination of algorithms.
                    1: certify primality using the Pocklington-Lehmer Test.
                    2: certify primality using the APRCL test.
        OUTPUT:
            gen -- 0 or 1
        """

def foo6():	"""
        divrem(x, y, long v): Euclidean division of x by y giving as a
        2-dimensional column vector the quotient and the remainder,
        with respect to v (to main variable if v is omitted).
        """

def foo7():	"""
        lex(x,y): Compare x and y lexicographically (1 if x>y, 0 if x==y, -1 if x<y)
        """

def foo8():	"""
        max(x,y): Return the maximum of x and y.
        """

def foo9():	"""
        min(x,y): Return the minumum of x and y.
        """

def foo10():	"""
        shift(x,n): shift x left n bits if n>=0, right -n bits if n<0.
        """

def foo11():	"""
        shiftmul(x,n): Return the product of x by 2^n (n>=0 or n<0).
        """

def foo12():	"""
        sign(x): Return the sign of x, where x is of type integer, real
        or fraction.
        """

def foo13():	"""
        vecmax(x): Return the maximum of the elements of the vector/matrix x,
        """

def foo14():	"""
        vecmin(x): Return the maximum of the elements of the vector/matrix x,
        """

def foo15():	"""
        Col(x): Transforms the object x into a column vector. 
        """

def foo16():	"""
        List(x): transforms the PARI vector or list x into a list.

        EXAMPLES:
            >>> v = pari([1,2,3])
            >>> v
            [1, 2, 3]
            >>> v.type()
            't_VEC'
            >>> w = v.List()
            >>> w
            List([1, 2, 3])
            >>> w.type()
            't_LIST'
        """

def foo17():	"""
        Mat(x): transforms any PARI x into a matrix.

        EXAMPLES:
            >>> x = pari(5)
            >>> x.type()
            't_INT'
            >>> y = x.Mat()
            >>> y
            Mat(5)
            >>> y.type()
            't_MAT'
            >>> x = pari('[1,2;3,4]')
            >>> x.type()
            't_MAT'
            >>> x = pari('[1,2,3,4]')
            >>> x.type()
            't_VEC'
            >>> y = x.Mat()
            >>> y
            Mat([1, 2, 3, 4])
            >>> y.type()
            't_MAT'
        """

def foo18():	"""
        Mod(x, y): creates the object x modulo y.

        INPUT:
            x -- gen
            y -- gen
            
        EXAMPLES:
            >>> z = pari(3)
            >>> x = z.Mod(pari(7))
            >>> x
            Mod(3, 7)
            >>> x**2
            Mod(2, 7)
            >>> x**100
            Mod(4, 7)
            >>> x.type()
            't_INTMOD'

            >>> f = pari("x^2 + x + 1")
            >>> g = pari("x")
            >>> a = g.Mod(f)
            >>> a
            Mod(x, x^2 + x + 1)
            >>> a*a
            Mod(-x - 1, x^2 + x + 1)
            >>> a.type()
            't_POLMOD'
        """

def foo19():	"""
        Pol(x): convert x (usually a vector or a power series) into a
        polynomial, starting with the leading coefficient

        INPUT:
            x -- gen
        OUTPUT:
            gen -- a polynomial
        EXAMPLES:
            >>> v = pari("[1,2,3,4]")
            >>> f = v.Pol()
            >>> f
            x^3 + 2*x^2 + 3*x + 4
            >>> f*f
            x^6 + 4*x^5 + 10*x^4 + 20*x^3 + 25*x^2 + 24*x + 16
            
            >>> v = pari("[1,2;3,4]")
            >>> v.Pol()
            [1, 3]~*x + [2, 4]~
        """

def foo20():	"""
        Polrev(x): convert x (usually a vector or a power series) into a
        polynomial, starting with the constant

        INPUT:
            x -- gen
        OUTPUT:
            gen -- a polynomial
        EXAMPLES:
            >>> v = pari("[1,2,3,4]")
            >>> f = v.Polrev()
            >>> f
            4*x^3 + 3*x^2 + 2*x + 1
            >>> f*f
            16*x^6 + 24*x^5 + 25*x^4 + 20*x^3 + 10*x^2 + 4*x + 1
            
        Note that Polrev does *not* reverse the coefficients of a polynomial!
            >>> f.Polrev()
            4*x^3 + 3*x^2 + 2*x + 1
            >>> v = pari("[1,2;3,4]")
            >>> v.Polrev()
            [2, 4]~*x + [1, 3]~
        """

def foo21():	"""
        Qfb(a,b,c,{D=0.}): binary quadratic form a*x^2+b*x*y+c*y^2.    D is optional
                           (0.0 by default) and initializes Shanks's distance if b^2-4*a*c>0

        INPUT:
            a -- gen
            b -- gen
            c -- gen
            D -- gen
            prec -- long (default to py_pari.PREC)
        OUTPUT:
            gen -- binary quadratic form
        EXAMPLES:
            >>> a = pari(3)
            >>> a.Qfb(pari(7), pari(2))
            Qfb(3, 7, 2, 0.E-288)
            
        """

def foo22():	"""
        """

def foo23():	"""
        """

def foo24():	"""
        """

def foo25():	"""
        """

def foo26():	"""
        """

def foo27():	"""
        """

def foo28():	"""
        """

def foo29():	"""
        """

def foo30():	"""
        """

def foo31():	"""
        """

def foo32():	"""
        """

def foo33():	"""
        """

def foo34():	"""
        """

def foo35():	"""
        """

def foo36():	"""
        """

def foo37():	"""
        """

def foo38():	"""
        """

def foo39():	"""
        """

def foo40():	"""
        """

def foo41():	"""
        """

def foo42():	"""
        """

def foo43():	"""
        """

def foo44():	"""
        """

def foo45():	"""
        """

def foo46():	"""
        """

def foo47():	"""
        """

def foo48():	"""
        """

def foo49():	"""
        """

def foo50():	"""
        """

def foo51():	"""
        """

def foo52():	"""
        """

def foo53():	"""
        """

def foo54():	"""
        """

def foo55():	"""
        """

def foo56():	"""
        """

def foo57():	"""
        """

def foo58():	"""
        """

def foo59():	"""
        """

def foo60():	"""
        """

def foo61():	"""
        """

def foo62():	"""
        """

def foo63():	"""
        """

def foo64():	"""
        """

def foo65():	"""
        e.elladd(z1, z2)

        Sum of the points z1 and z2 on the elliptic curve e.

        INPUT:
            e -- elliptic curve E
            z1 -- point on E
            z2 -- point on E
            
        OUTPUT:
            point on E

        EXAMPLES:
            >>> e = pari("ellinit([0, 1, 1, -2, 0])")
            >>> z1 = pari("[1,0,1]")
            >>> z2 = pari("[-1,1,1]")
            >>> e.elladd(z1, z2)
            [-3/4, -15/8]
        """

def foo66():	"""
        e.ellak(n)

        Returns the coefficient a_n of the L-function of the elliptic
        curve e, i.e. the coefficient of a newform of weight 2 newform.
        The curve e must be a medium or long vector of the type given
        by ellinit. For this function to work for every n and not
        just those prime to the conductor, e must be a minimal Weierstrass
        equation. If this is not the case, use the function
        ellminimalmodel first before using ellak.

        INPUT:
            n -- integer ..
        """

def foo67():	"""
        """

def foo68():	"""
        ellchangepoint(x,y)

        change data on point or vector of points x on an elliptic curve according
        to y=[u,r,s,t]
        """

def foo69():	"""
        ellheightmatrix(e,x)

        Returns the height matrix for vector of points x on elliptic curve e using
        theta functions.
        """

def foo70():	"""
        ellinit(x,{flag=0}): x being the vector [a1,a2,a3,a4,a6], gives
        the vector: [a1,a2,a3,a4,a6,
                    b2,b4,b6,b8,
                    c4,c6,
                    delta,j,
                    [e1,e2,e3],
                    w1,w2,eta1,eta2,area].
        If the curve is defined over a p-adic field, the last six components
        are replaced by root,u^2,u,q,w,0. If optional flag is 1, omit them
        altogether.
        """

def foo71():	"""
    Create the PARI object got by evaluating s using PARI.
    """

def foo72():	"""
    Stack size, in bytes
    """

def foo73():	"""
    How much memory in megabytes is currently being used on the PARI stack.
    """

def foo74():	"""
    How much memory in bytes is currently available on the PARI stack.
    """

def foo75():	"""
    nth_prime(n): returns the n-th prime, where n is a C-int
    """


if __name__ ==  '__main__':
    import doctest, sys
    doctest.testmod(sys.modules[__name__])
