# Buhler-Gross algorithm for computing L-series derivatives

# Based on an implementation in GP by tom@womack.net and
# jec@maths.nottingham.ac.uk

# This is practical for any rank and conductors <= 10^10.

# Section 0: prime-number utility which really should be
# built-in. This version due to Karim (reference for upper and lower
# bounds is Rosser & Schoenfeld, Approximate formulas for some functions
# of prime numbers, Illinois J Math 6 (1962) pp 64-94)
from py_pari import *

P = pari  # coerce to a pari object

def pith(x):
    assert isinstance(x, gen)

    if x <= P(2):
        return x == P(2)
    lx = log(x)
    l = floor (x / lx)
    r = floor(l * (P(1) + P(3)/(P(2)*lx)))
    while r - l > P(1):
        m = (l+r) >> 1
        if nth_prime(m) <= x:
            l = m
        else:
            r = m
    return l


